@@ -11,7 +11,7 @@
             Purpose: This abstracts the Card Edge Interface APDU's
 	             into client side function calls.
  
-$Id: musclecardApplet.c,v 1.1.1.1 2003/10/03 19:11:56 rousseau Exp $
+$Id: musclecardApplet.c,v 1.7 2006-11-25 20:55:04 rousseau Exp $
 ********************************************************************/
 #ifdef WIN32
 #include "../win32/MCardPlugin.h"
@@ -150,15 +150,14 @@ MSC_RV PL_MSCGetCapabilities( MSCLPTokenConnection pConnection, MSCULong32 Tag,
     break;
 
   case MSC_TAG_SUPPORT_CRYPTOALG:
-    ulValue = MSC_SUPPORT_RSA | MSC_SUPPORT_DSA |
+    ulValue = MSC_SUPPORT_RSA |
       MSC_SUPPORT_DES | MSC_SUPPORT_3DES;
     tagType = 4;
     break;
 
   case MSC_TAG_CAPABLE_RSA:
     ulValue = MSC_CAPABLE_RSA_1024 | MSC_CAPABLE_RSA_768 |
-      MSC_CAPABLE_RSA_NOPAD | MSC_CAPABLE_RSA_KEYGEN |
-      MSC_CAPABLE_RSA_PKCS1;
+      MSC_CAPABLE_RSA_NOPAD | MSC_CAPABLE_RSA_KEYGEN;
     tagType = 4;
     break;
 
@@ -245,7 +244,7 @@ MSC_RV PL_MSCGetCapabilities( MSCLPTokenConnection pConnection, MSCULong32 Tag,
     break;
 
   case MSC_TAG_CAPABLE_KEY_AUTH:
-    usValue = MSC_AUT_PIN_0;
+    usValue = MSC_AUT_PIN_1;
     tagType = 2;
     break;
 
@@ -1056,6 +1055,28 @@ MSC_RV PL_MSCListKeys( MSCLPTokenConnection pConnection, MSCUChar8 seqOption,
 
     currentPointer += MSC_SIZEOF_ACLVALUE;
 
+    switch(pKeyInfo->keyType)
+    {
+        case MSC_KEY_RSA_PUBLIC:
+        case MSC_KEY_RSA_PRIVATE:
+        case MSC_KEY_RSA_PRIVATE_CRT:
+            pKeyInfo->keyPolicy.cipherMode = MSC_KEYPOLICY_MODE_RSA_NOPAD;
+            pKeyInfo->keyPolicy.cipherDirection = MSC_KEYPOLICY_DIR_SIGN | MSC_KEYPOLICY_DIR_VERIFY |
+                MSC_KEYPOLICY_DIR_ENCRYPT | MSC_KEYPOLICY_DIR_DECRYPT;
+            break;
+        case MSC_KEY_DES:
+        case MSC_KEY_3DES:
+        case MSC_KEY_3DES3:
+            pKeyInfo->keyPolicy.cipherMode = MSC_KEYPOLICY_MODE_DES_ECB_NOPAD;
+            pKeyInfo->keyPolicy.cipherDirection = MSC_KEYPOLICY_DIR_ENCRYPT | MSC_KEYPOLICY_DIR_DECRYPT;
+            break;
+            
+        default:
+            pKeyInfo->keyPolicy.cipherMode = 0;
+            pKeyInfo->keyPolicy.cipherDirection = 0;
+            break;
+    }
+
     return convertSW(&apduResponse[currentPointer]);
   } else {
     return MSC_UNSPECIFIED_ERROR;
@@ -1947,7 +1968,7 @@ void MemCopyTo32(MSCPULong32 destValue, MSCPUChar8 srcValue) {
 }
 
 MSCUShort16 getUShort16(MSCPUChar8 srcValue) {
-  return ( (((MSCUShort16)srcValue[0]) << 8) || srcValue[1] );
+  return ( (((MSCUShort16)srcValue[0]) << 8) + srcValue[1] );
 }
 
 void setUShort16(MSCPUChar8 dstValue, MSCUShort16 srcValue) {
