@@ -57,7 +57,7 @@ struct secure_data {
   const char *user;
 };
 
-void pam_release_data(struct secure_data *data)
+static void pam_release_data(struct secure_data *data)
 {
   /* overwrite data */
   memset(data, 0, sizeof(struct secure_data));
@@ -65,7 +65,7 @@ void pam_release_data(struct secure_data *data)
   free(data);
 }
 
-int pam_get_pin(pam_handle_t *pamh, char *pin, char* text, int oitem, int nitem)
+static int pam_get_pin(pam_handle_t *pamh, char *pin, char* text, int oitem, int nitem)
 {
   int rv;
   const char *old_pin;
@@ -114,7 +114,7 @@ int pam_get_pin(pam_handle_t *pamh, char *pin, char* text, int oitem, int nitem)
   return PAM_CRED_INSUFFICIENT;
 }
 
-int pam_show_message(pam_handle_t *pamh, char* text)
+static int pam_show_message(pam_handle_t *pamh, char* text)
 {
   int rv;
   struct pam_conv *conv;
@@ -137,7 +137,7 @@ int pam_show_message(pam_handle_t *pamh, char* text)
   return PAM_SUCCESS;
 }
 
-int readRootCert(X509 **userCert, MSCTokenConnection pConnection, 
+static int readRootCert(X509 **userCert, MSCTokenConnection pConnection, 
 		 struct secure_data *sd) {
   EVP_PKEY *pubkey;
   int index, rv;
@@ -252,7 +252,7 @@ int readRootCert(X509 **userCert, MSCTokenConnection pConnection,
   return 0;
 }
 
-int readUserPubKey(EVP_PKEY **userCert, MSCTokenConnection pConnection, 
+static int readUserPubKey(EVP_PKEY **userCert, MSCTokenConnection pConnection, 
 		 struct secure_data *sd) {
   int rv = 0;
   EVP_PKEY *tmpCert;
@@ -266,6 +266,8 @@ int readUserPubKey(EVP_PKEY **userCert, MSCTokenConnection pConnection,
    specified file overrides the end user's default certificate in their 
    home directory  - so userpath is defined for debugging only */
 
+  (void)pConnection;
+
   if (strlen(pr.userpath)>0) {
 	snprintf(homeFile, sizeof(homeFile), "%s%s/.muscle/%s", pr.userpath, sd->user, pr.certname);  
   } else {
