@@ -195,7 +195,7 @@ void util_ParsePreference(char *buf, int buf_size)
 **  none
 ******************************************************************************/
 
-int util_ReadPreferences()
+int util_ReadPreferences(void)
 {
   int rv = 0;
   FILE *fp;
