@@ -38,7 +38,7 @@ extern struct preferences pr;
 void util_ParsePreference(char *buf, int buf_size);
 
 /* Parse the configuration file */
-int util_ReadPreferences();
+int util_ReadPreferences(void);
 
 /* Check the permissions of the file */
 int util_CheckFile (char *file, char *user);
