@@ -1,6 +1,6 @@
 /******************************************************************************
 ** 
-**  $Id: cryptoki.h,v 1.7 2006-11-25 20:55:04 rousseau Exp $
+**  $Id: cryptoki.h,v 1.9 2009-06-24 16:21:36 rousseau Exp $
 **
 **  Package: PKCS-11
 **  Author : Chris Osgood <oznet@mac.com>
@@ -299,8 +299,8 @@ extern P11_State st;
 ******************************************************************************/
 
 /* p11x_async.c */
-CK_RV async_StartSlotWatcher();
-CK_RV async_StopSlotWatcher();
+CK_RV async_StartSlotWatcher(void);
+CK_RV async_StopSlotWatcher(void);
  void *async_WatchSlots(void *parent_pid);
  void async_SignalHandler(int sig);
 MSCULong32 async_TokenEventCallback(MSCTokenInfo *tokenInfo, MSCULong32 len, void *data);
@@ -309,22 +309,22 @@ MSCULong32 async_TokenEventCallback(MSCTokenInfo *tokenInfo, MSCULong32 len, voi
 int padRSAType1(CK_BYTE* to, CK_ULONG toLen, CK_BYTE *from, CK_ULONG fromLen);
 
 /* p11x_debug.c */
-void debug_Init();
+void debug_Init(void);
 void debug_CheckCorrupt(size_t i);
-void debug_Check();
+void debug_Check(void);
 void *debug_Malloc(size_t size, int line, char *file);
 void debug_Free(void *ptr, int line, char *file);
 void *debug_Calloc(size_t size, int line, char *file);
 
 /* p11x_error.c */
-CK_RV error_LogCmd(CK_RV err, CK_RV cond, CK_CHAR *file, CK_LONG line, char *(*stringifyFn)(CK_RV));
- char *error_Stringify(CK_RV rv);
+CK_RV error_LogCmd(CK_RV err, CK_RV cond, CK_CHAR *file, CK_LONG line, const char *(*stringifyFn)(CK_RV));
+const char *error_Stringify(CK_RV rv);
 
 /* p11x_log.c */
-void log_Start(char *func);
-void log_End(char *func, CK_RV rv);
-void log_Err(char *msg, char *file, CK_LONG line);
-void log_Log(CK_ULONG level, char *format, ...);
+void log_Start(const char *func);
+void log_End(const char *func, CK_RV rv);
+void log_Err(const char *msg, const char *file, CK_LONG line);
+void log_Log(CK_ULONG level, const char *format, ...);
 
 /* p11x_object.c */
  void object_FreeAllObjects(CK_SLOT_ID slotID, P11_Object *list);
@@ -341,7 +341,7 @@ CK_RV object_UpdateKeyInfo(P11_Session *session, CK_OBJECT_HANDLE *hObject, MSCK
 CK_RV object_UpdateObjectInfo(P11_Session *session, CK_OBJECT_HANDLE *hObject, MSCObjectInfo *pObjectInfo);
 /* End of replacements */
 
-CK_RV object_FreeTokenObjects();
+CK_RV object_FreeTokenObjects(CK_SLOT_ID slotID);
 CK_RV object_AddAttribute(P11_Object *object, CK_ATTRIBUTE_TYPE type, CK_BBOOL token, CK_BYTE *value, CK_ULONG value_len, P11_Attrib **attrib);
 CK_RV object_MatchAttrib(CK_ATTRIBUTE *attrib, P11_Object *object);
 CK_RV object_TemplateGetAttrib(CK_ATTRIBUTE_TYPE type, CK_ATTRIBUTE *attrib, CK_ULONG attrib_count, CK_ATTRIBUTE **attrib_out);
@@ -414,11 +414,11 @@ CK_ULONG object_UserMode(P11_Session *session);
 
 /* p11x_prefs.c */
 void util_ParsePreference(char *buf, CK_ULONG buf_size);
-CK_RV util_ReadPreferences();
+CK_RV util_ReadPreferences(void);
 
 /* p11x_state.c */
-CK_RV state_Init();
-CK_RV state_Free();
+CK_RV state_Init(void);
+CK_RV state_Free(void);
 
 /* p11x_slot.c */
    CK_RV slot_BeginTransaction(CK_ULONG slotID);
@@ -435,16 +435,16 @@ CK_ULONG slot_MechanismCount(P11_MechInfo *mech);
     void slot_FreeAllMechanisms(P11_MechInfo *list);
    CK_RV slot_AddMechanism(P11_Slot *slot, CK_MECHANISM_TYPE type, P11_MechInfo **mech_info);
    CK_RV slot_UpdateToken(CK_ULONG slotID);
-   CK_RV slot_UpdateSlotList();
-   CK_RV slot_FreeAllSlots();
+   CK_RV slot_UpdateSlotList(void);
+   CK_RV slot_FreeAllSlots(void);
    CK_RV slot_DisconnectSlot(CK_ULONG slotID, CK_ULONG action);
    CK_RV slot_PublicMode(CK_ULONG slotID);
    CK_RV slot_UserMode(CK_ULONG slotID);
    CK_RV slot_TokenPresent(CK_ULONG slotID);
-   CK_RV slot_TokenChanged();
-   CK_RV slot_AsyncUpdateSlot();
+   CK_RV slot_TokenChanged(void);
+   CK_RV slot_AsyncUpdateSlot(void);
     void slot_BlankTokenInfo(CK_TOKEN_INFO *token_info);
-   CK_RV slot_ReverifyPins();
+   CK_RV slot_ReverifyPins(void);
 
    /* Added by Netscape */
    CK_RV slot_ReverifySlotPins(P11_Slot* slot, CK_ULONG slotID);
@@ -462,12 +462,12 @@ CK_RV session_FreeSession(P11_Session *session);
 /* end of replacements */
 
 /* p11x_thread_xxx.c */
-CK_RV thread_Initialize();
+CK_RV thread_Initialize(void);
 CK_RV thread_InitFunctions(CK_CREATEMUTEX fn_init,
                            CK_DESTROYMUTEX fn_destroy,
                            CK_LOCKMUTEX fn_lock,
                            CK_UNLOCKMUTEX fn_unlock);
-CK_RV thread_Finalize();
+CK_RV thread_Finalize(void);
 CK_RV thread_MutexInit(P11_Mutex *mutex);
 CK_RV thread_MutexDestroy(P11_Mutex mutex);
 CK_RV thread_MutexLock(P11_Mutex mutex);
@@ -481,7 +481,7 @@ CK_ULONG util_strpadlen(CK_CHAR *string, CK_ULONG max_len);
 #ifndef __USE_GNU
    size_t strnlen(const char *__string, size_t __maxlen);
 #endif /* __USE_GNU */
-CK_BBOOL util_IsLittleEndian();
+CK_BBOOL util_IsLittleEndian(void);
 
 /* p11x_msc.c */
 #include "p11x_msc.h"
