@@ -1,6 +1,6 @@
 /******************************************************************************
 ** 
-**  $Id: p11x_async.c,v 1.7 2006-11-25 20:55:04 rousseau Exp $
+**  $Id: p11x_async.c,v 1.9 2009-06-24 16:21:36 rousseau Exp $
 **
 **  Package: PKCS-11
 **  Author : Chris Osgood <oznet@mac.com>
@@ -30,7 +30,7 @@
 **  CKR_FUNCTION_FAILED on general error
 **  CKR_OK
 *******************************************************************************/
-CK_RV async_StartSlotWatcher()
+CK_RV async_StartSlotWatcher(void)
 {
     CK_RV rv = CKR_OK;
     CK_ULONG i;
@@ -86,7 +86,7 @@ CK_RV async_StartSlotWatcher()
 ** Returns:
 **  CKR_OK
 *******************************************************************************/
-CK_RV async_StopSlotWatcher()
+CK_RV async_StopSlotWatcher(void)
 {
     CK_RV rv = CKR_OK;
 
