@@ -1,6 +1,6 @@
 /******************************************************************************
 ** 
-**  $Id: p11x_error.c,v 1.7 2006-11-25 20:55:04 rousseau Exp $
+**  $Id: p11x_error.c,v 1.9 2009-06-24 16:21:36 rousseau Exp $
 **
 **  Package: PKCS-11
 **  Author : Chris Osgood <oznet@mac.com>
@@ -28,7 +28,7 @@
 ** Returns:
 **  The error code that was passed in
 *******************************************************************************/
-CK_RV error_LogCmd(CK_RV err, CK_RV cond, CK_CHAR *file, CK_LONG line, char *(*stringifyFn)(CK_RV))
+CK_RV error_LogCmd(CK_RV err, CK_RV cond, CK_CHAR *file, CK_LONG line, const char *(*stringifyFn)(CK_RV))
 {
     if (err != cond)
         log_Log(LOG_MED, "(%s %ld): error: 0x%lX \"%s\"", file, line, err, stringifyFn(err));
@@ -47,9 +47,9 @@ CK_RV error_LogCmd(CK_RV err, CK_RV cond, CK_CHAR *file, CK_LONG line, char *(*s
 ** Returns:
 **  A static string error message (make this const?)
 *******************************************************************************/
-char *error_Stringify(CK_RV rv)
+const char *error_Stringify(CK_RV rv)
 {
-    char *error;
+    const char *error;
 
     switch(rv)
     {
