@@ -1,6 +1,6 @@
 /******************************************************************************
 ** 
-**  $Id: p11x_log.c,v 1.7 2006-11-25 20:55:04 rousseau Exp $
+**  $Id: p11x_log.c,v 1.9 2009-06-24 16:21:36 rousseau Exp $
 **
 **  Package: PKCS-11
 **  Author : Chris Osgood <oznet@mac.com>
@@ -30,7 +30,7 @@
 ** Returns:
 **  none
 *******************************************************************************/
-void log_Start(char *func)
+void log_Start(const char *func)
 {
     log_Log(LOG_LOW, "+%s : start", func);
 }
@@ -46,9 +46,9 @@ void log_Start(char *func)
 ** Returns:
 **  none
 *******************************************************************************/
-void log_End(char *func, CK_RV rv)
+void log_End(const char *func, CK_RV rv)
 {
-    if (CKR_ERROR(rv));
+    if (CKR_ERROR(rv)) {}
     log_Log(LOG_LOW, " -%s : end RV(0x%lX)", func, rv);
 }
 
@@ -63,7 +63,7 @@ void log_End(char *func, CK_RV rv)
 ** Returns:
 **  none
 *******************************************************************************/
-void log_Err(char *msg, char *file, CK_LONG line)
+void log_Err(const char *msg, const char *file, CK_LONG line)
 {
     log_Log(LOG_MED, "Error (%s %ld): %s", file, line, msg);
 }
@@ -79,7 +79,7 @@ void log_Err(char *msg, char *file, CK_LONG line)
 ** Returns:
 **  none
 *******************************************************************************/
-void log_Log(CK_ULONG level, char *msg, ...)
+void log_Log(CK_ULONG level, const char *msg, ...)
 {
     va_list args;
 
