@@ -1,6 +1,6 @@
 /******************************************************************************
 ** 
-**  $Id: p11x_msc.c,v 1.7 2006-11-25 20:55:04 rousseau Exp $
+**  $Id: p11x_msc.c,v 1.9 2009-06-24 16:21:36 rousseau Exp $
 **
 **  Package: PKCS-11
 **  Author : Chris Osgood <oznet@mac.com>
@@ -121,7 +121,7 @@ MSC_RV msc_CallbackForTokenEvent(
 }
 
     /* Cancels all callback registrations */
-MSC_RV msc_CallbackCancelEvent()
+MSC_RV msc_CallbackCancelEvent(void)
 {
     MSC_RV rv;
 
