@@ -1,6 +1,6 @@
 /******************************************************************************
 ** 
-**  $Id: p11x_object.c,v 1.7 2006-11-25 20:55:04 rousseau Exp $
+**  $Id: p11x_object.c,v 1.9 2009-06-24 16:21:36 rousseau Exp $
 **
 **  Package: PKCS-11
 **  Author : Chris Osgood <oznet@mac.com>
@@ -675,7 +675,7 @@ CK_RV object_AddBoolAttribute(CK_ATTRIBUTE_TYPE type, CK_BBOOL value, P11_Object
 CK_RV object_MatchAttrib(CK_ATTRIBUTE *attrib, P11_Object *object)
 {
     CK_RV rv;
-    P11_Attrib *obj_attrib;
+    P11_Attrib *obj_attrib = NULL;
     CK_BYTE *reverse, *forward, temp;
     CK_ULONG i;
 
@@ -816,8 +816,8 @@ CK_RV object_RSAGenKeyPair(P11_Session *session,
     P11_Slot *slot = &st.slots[session->session.slotID - 1];
     P11_Object *objectPub;
     P11_Object *objectPrv;
-    CK_ATTRIBUTE *attrib;
-    P11_Attrib *p11_attrib;
+    CK_ATTRIBUTE *attrib = NULL;
+    P11_Attrib *p11_attrib = NULL;
     MSCKeyInfo keyInfo;
     MSCKeyInfo keyInfoPub;
     MSCKeyInfo keyInfoPrv;
@@ -1645,7 +1645,7 @@ CK_RV object_InferClassAttributes(P11_Session *session, P11_Object *object)
 {
     CK_RV rv = CKR_OK;
     CK_ATTRIBUTE attrib;
-    P11_Attrib *obj_attrib, *t_attrib;
+    P11_Attrib *obj_attrib = NULL, *t_attrib;
     CK_OBJECT_CLASS obj_class;
     CK_BYTE buf[4096]; /* Fixme: don't hardcode this */
     CK_ULONG len;
@@ -1956,7 +1956,7 @@ CK_RV object_CreateCertificate(P11_Session *session, P11_Object *object)
 /*    P11_Session *session = (P11_Session *)hSession; */
     P11_Slot *slot = &st.slots[session->session.slotID - 1];
     P11_Object *object_l;
-    P11_Attrib *attrib;
+    P11_Attrib *attrib = NULL;
     CK_BYTE tag, last;
     CK_BYTE classRevCheck[sizeof(CK_ULONG)];    
 
@@ -2025,8 +2025,8 @@ CK_RV object_CreatePublicKey(P11_Session *session, P11_Object *object)
     P11_Slot *slot = &st.slots[session->session.slotID - 1];
     CK_BYTE keyNum = 0;
     MSCKeyInfo keyInfo;
-    P11_Attrib *modulus;
-    P11_Attrib *public_exponent;
+    P11_Attrib *modulus = NULL;
+    P11_Attrib *public_exponent = NULL;
     CK_ULONG keySize = 1024;
     CK_BYTE *keyBlob;
     CK_ULONG keyBlobSize;
@@ -2126,14 +2126,14 @@ CK_RV object_CreatePrivateKey(P11_Session *session, P11_Object *object)
     P11_Slot *slot = &st.slots[session->session.slotID - 1];
     CK_BYTE keyNum = 0;
     MSCKeyInfo keyInfo;
-    P11_Attrib *modulus;
+    P11_Attrib *modulus = NULL;
     P11_Attrib *private_exponent;
     P11_Attrib *public_exponent;
-    P11_Attrib *prime_1;
-    P11_Attrib *prime_2;
-    P11_Attrib *exponent_1;
-    P11_Attrib *exponent_2;
-    P11_Attrib *coefficient;
+    P11_Attrib *prime_1 = NULL;
+    P11_Attrib *prime_2 = NULL;
+    P11_Attrib *exponent_1 = NULL;
+    P11_Attrib *exponent_2 = NULL;
+    P11_Attrib *coefficient = NULL;
     CK_ULONG keySize = 1024;
     CK_BYTE *keyBlob;
     CK_ULONG keyBlobSize;
@@ -2250,7 +2250,7 @@ CK_RV object_CreateObject(P11_Session *session, P11_Object *object)
 /*    P11_Session *session = (P11_Session *)hSession; */
     P11_Slot *slot = &st.slots[session->session.slotID - 1];
     P11_Object *object_l;
-    P11_Attrib *attrib;
+    P11_Attrib *attrib = NULL;
     CK_BYTE tag, last;
     CK_BYTE classRevCheck[sizeof(CK_ULONG)];      
 
@@ -2358,7 +2358,7 @@ CK_ULONG object_UserMode(P11_Session *session)
     else
     {
         object_l = st.slots[session->session.slotID - 1].objects;
-        while(object_l && object_l->next)
+        while(object_l)
         {
             if (object_l->sensitive)
             {
