@@ -1,6 +1,6 @@
 /******************************************************************************
 ** 
-**  $Id: p11x_prefs.c,v 1.7 2006-11-25 20:55:04 rousseau Exp $
+**  $Id: p11x_prefs.c,v 1.9 2009-06-24 16:21:36 rousseau Exp $
 **
 **  Package: PKCS-11
 **  Author : Chris Osgood <oznet@mac.com>
@@ -374,7 +374,7 @@ loser:
 **  none
 *******************************************************************************/
 #ifndef WIN32
-CK_RV util_ReadPreferences()
+CK_RV util_ReadPreferences(void)
 {
     CK_RV rv = CKR_OK;
     FILE *fp = NULL;
@@ -384,7 +384,7 @@ CK_RV util_ReadPreferences()
     char buf[1024];
     char *homeenv;
 
-    if (homeenv = getenv("HOME")) {
+    if ((homeenv = getenv("HOME"))) {
         strncpy(rcfilepath, homeenv, sizeof(rcfilepath) - sizeof(rcfilename) - 1);
         strcat(rcfilepath, rcfilename);
         fp = fopen(rcfilepath, "rb");
