@@ -1,6 +1,6 @@
 /******************************************************************************
 ** 
-**  $Id: p11x_slot.c,v 1.7 2006-11-25 20:55:04 rousseau Exp $
+**  $Id: p11x_slot.c,v 1.9 2009-06-24 16:21:36 rousseau Exp $
 **
 **  Package: PKCS-11
 **  Author : Chris Osgood <oznet@mac.com>
@@ -766,7 +766,7 @@ CK_RV slot_UpdateToken(CK_ULONG slotID)
 **  CKR_FUNCTION_FAILED on general error
 **  CKR_OK
 *******************************************************************************/
-CK_RV slot_UpdateSlotList()
+CK_RV slot_UpdateSlotList(void)
 {
     CK_RV rv = CKR_OK;
     CK_ULONG i;
@@ -834,7 +834,7 @@ CK_RV slot_UpdateSlotList()
 ** Returns:
 **  CKR_OK
 *******************************************************************************/
-CK_RV slot_FreeAllSlots()
+CK_RV slot_FreeAllSlots(void)
 {
     CK_RV rv = CKR_OK;
     CK_ULONG i;
@@ -1067,7 +1067,7 @@ CK_RV slot_TokenPresent(CK_ULONG slotID)
 **  CKR_CRYPTOKI_NOT_INITIALIZED
 **  CKR_OK
 *******************************************************************************/
-CK_RV slot_TokenChanged()
+CK_RV slot_TokenChanged(void)
 {
     CK_RV rv = CKR_OK;
     CK_ULONG i;
@@ -1219,7 +1219,7 @@ CK_RV slot_ReverifySlotPins(P11_Slot *slot, CK_ULONG slotID)
 **  Error from slot_VerifyPIN
 **  CKR_OK
 *******************************************************************************/
-CK_RV slot_ReverifyPins()
+CK_RV slot_ReverifyPins(void)
 {
     CK_RV rv = CKR_OK;
     CK_ULONG i;
