@@ -1,6 +1,6 @@
 /******************************************************************************
 ** 
-**  $Id: p11x_state.c,v 1.7 2006-11-25 20:55:04 rousseau Exp $
+**  $Id: p11x_state.c,v 1.9 2009-06-24 16:21:36 rousseau Exp $
 **
 **  Package: PKCS-11
 **  Author : Chris Osgood <oznet@mac.com>
@@ -54,7 +54,7 @@ P11_State st = { 0,                             /* initialized             */
 **  CKR_HOST_MEMORY if memory alloc fails
 **  CKR_OK
 *******************************************************************************/
-CK_RV state_Init()
+CK_RV state_Init(void)
 {
     CK_RV rv = CKR_OK;
 
@@ -81,7 +81,7 @@ CK_RV state_Init()
 **  Error from slot_FreeAllSlots (not checked and everything gets blasted)
 **  CKR_OK
 *******************************************************************************/
-CK_RV state_Free()
+CK_RV state_Free(void)
 {
     CK_RV rv = CKR_OK;
 
