@@ -1,6 +1,6 @@
 /******************************************************************************
 **
-**  $Id: p11x_thread.c,v 1.7 2006-11-25 20:55:04 rousseau Exp $
+**  $Id: p11x_thread.c,v 1.9 2009-06-24 16:21:36 rousseau Exp $
 **
 **  Package: PKCS-11
 **  Author : Chris Osgood
@@ -37,7 +37,7 @@ static CK_UNLOCKMUTEX p11_unlockmutex = 0;
 **  CKR_FUNCTION_FAILED on error
 **  CKR_OK
 *******************************************************************************/
-CK_RV thread_Initialize()
+CK_RV thread_Initialize(void)
 {
     CK_RV rv = CKR_OK;
 
@@ -103,7 +103,7 @@ CK_RV thread_InitFunctions(CK_CREATEMUTEX fn_createmutex,
 **  CKR_FUNCTION_FAILED on general error
 **  CKR_OK
 *******************************************************************************/
-CK_RV thread_Finalize()
+CK_RV thread_Finalize(void)
 {
     CK_RV rv = CKR_OK;
 
