@@ -1,6 +1,6 @@
 /******************************************************************************
 ** 
-**  $Id: p11x_util.c,v 1.7 2006-11-25 20:55:04 rousseau Exp $
+**  $Id: p11x_util.c,v 1.9 2009-06-24 16:21:36 rousseau Exp $
 **
 **  Package: PKCS-11
 **  Author : Chris Osgood <oznet@mac.com>
@@ -163,7 +163,7 @@ size_t strnlen(const char *__string, size_t __maxlen)
 ** Returns:
 **  True/False if machine is little endian or not
 *******************************************************************************/
-CK_BBOOL util_IsLittleEndian()
+CK_BBOOL util_IsLittleEndian(void)
 {
     CK_ULONG rv = 1;
 
